@@ -140,6 +140,8 @@
 #'  \item $PCA_output - princomp object: the result output of the PCA analysis
 #'  \item $type - the character string describing type of analysis: monthly or monthly
 #'  \item $reference_window - character string, which reference window was used for calculations
+#'  \item $aggregated_climate_primary - matrix with all aggregated climate series of primary data
+#'  \item $aggregated_climate_control - matrix with all aggregated climate series of control data
 #'}
 #'
 #' @export
@@ -690,6 +692,13 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
   # B) Chunks are used if fixed.withd == 0
     # B.1 method == "cor"
 
+  # these are lists for climate and and holder for saving mm1 and mm2
+  list_climate_primary <- list()
+  list_climate_control <- list()
+
+  mm1 <- 1
+  mm2 <- 1
+
   # A.1 method = "cor"
   if (fixed_width != 0 & method == "cor") {
 
@@ -796,6 +805,19 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
         colnames(my_temporal_data) <- c("x", "y", "z")
 
 
+        x1_list <- x1
+        colnames(x1_list) <- paste0(j + 1, "_" ,j + fixed_width)
+        row.names(x1_list) <- row.names(env_data_primary)
+        list_climate_primary[[mm1]] <- x1_list
+        mm1 = mm1 + 1
+
+        x2_list <- x2
+        colnames(x2_list) <- paste0(j + 1, "_" ,j + fixed_width)
+        row.names(x2_list) <- row.names(env_data_control)
+        list_climate_control[[mm2]] <- x2_list
+        mm2 = mm2 + 1
+
+
         if (boot == FALSE){
 
           temporal_correlation <- partial.r(data=my_temporal_data, x=c("x","y"), y="z", use="pairwise",method = pcor_method)[2]
@@ -1033,11 +1055,20 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
        colnames(my_temporal_data) <- c("x", "y", "z")
 
 
+       x1_list <- x1
+       colnames(x1_list) <- paste0(j + 1, "_" ,j + K)
+       row.names(x1_list) <- row.names(env_data_primary)
+       list_climate_primary[[mm1]] <- x1_list
+       mm1 = mm1 + 1
+
+       x2_list <- x2
+       colnames(x2_list) <- paste0(j + 1, "_" ,j + K)
+       row.names(x2_list) <- row.names(env_data_control)
+       list_climate_control[[mm2]] <- x2_list
+       mm2 = mm2 + 1
 
        if (boot == FALSE){
 
-
-
          temporal_correlation <- partial.r(data=my_temporal_data, x=c("x","y"), y="z", use="pairwise",method = pcor_method)[2]
 
          if (reference_window == 'start'){
@@ -1786,7 +1817,9 @@ for (m in 1:length(empty_list_datasets)){
                        optimized_return = x1_full,
                        optimized_return_all = x1_full_original,
                        transfer_function = p1, temporal_stability = temporal_stability,
-                       cross_validation = cross_validation)
+                       cross_validation = cross_validation,
+                       aggregated_climate_primary = do.call(cbind, list_climate_primary),
+                       aggregated_climate_control = do.call(cbind, list_climate_control))
   }
 
   if (method == "cor"){
@@ -1795,7 +1828,9 @@ for (m in 1:length(empty_list_datasets)){
                        optimized_return = x1_full,
                        optimized_return_all = x1_full_original,
                        transfer_function = p1, temporal_stability = temporal_stability,
-                       cross_validation = cross_validation)
+                       cross_validation = cross_validation,
+                       aggregated_climate_primary = do.call(cbind, list_climate_primary),
+                       aggregated_climate_control = do.call(cbind, list_climate_control))
   }
 
     plot_heatmapA <- plot_heatmap(final_list, reference_window = reference_window, type = "monthly")
@@ -1835,7 +1870,9 @@ for (m in 1:length(empty_list_datasets)){
                          type = "monthly",
                          reference_window = reference_window,
                          boot_lower = temporal_matrix_lower,
-                         boot_upper = temporal_matrix_upper)
+                         boot_upper = temporal_matrix_upper,
+                         aggregated_climate_primary = do.call(cbind, list_climate_primary),
+                         aggregated_climate_control = do.call(cbind, list_climate_control))
     }
 
     if (method == "cor"){
@@ -1852,7 +1889,10 @@ for (m in 1:length(empty_list_datasets)){
                          type = "monthly",
                          reference_window = reference_window,
                          boot_lower = temporal_matrix_lower,
-                         boot_upper = temporal_matrix_upper)
+                         boot_upper = temporal_matrix_upper,
+                         aggregated_climate_primary = do.call(cbind, list_climate_primary),
+                         aggregated_climate_control = do.call(cbind, list_climate_control)
+                         )
     }
 
     class(final_list) <- "dmrs"
